OrgFreedesktopNetworkManagerSettings class
Methods
-
callAddConnection(Map<String, Map<String, DBusValue>> connection, {bool noAutoStart = false, bool allowInteractiveAuthorization = false})
→ Future<DBusObjectPath>
-
Invokes org.freedesktop.NetworkManager.Settings.AddConnection()
-
callDelete({bool noAutoStart = false, bool allowInteractiveAuthorization = false})
→ Future<void>
-
Invokes org.freedesktop.NetworkManager.Settings.Connection.Delete()
-
callGetConnectionByUuid(String uuid, {bool noAutoStart = false, bool allowInteractiveAuthorization = false})
→ Future<DBusObjectPath>
-
Invokes org.freedesktop.NetworkManager.Settings.GetConnectionByUuid()
-
callGetSettings({bool noAutoStart = false, bool allowInteractiveAuthorization = false})
→ Future<Map<String, Map<String, DBusValue>>>
-
Invokes org.freedesktop.NetworkManager.Settings.Connection.GetSettings()
-
callListConnections({bool noAutoStart = false, bool allowInteractiveAuthorization = false})
→ Future<List<DBusObjectPath>>
-
Invokes org.freedesktop.NetworkManager.Settings.ListConnections()
-
callMethod(String? interface, String name, Iterable<DBusValue> values, {DBusSignature? replySignature, bool noReplyExpected = false, bool noAutoStart = false, bool allowInteractiveAuthorization = false})
→ Future<DBusMethodSuccessResponse>
-
Invokes a method on this object.
Throws
DBusMethodResponseException if the remote side returns an error.
inherited
-
callSaveHostname(String hostname, {bool noAutoStart = false, bool allowInteractiveAuthorization = false})
→ Future<void>
-
Invokes org.freedesktop.NetworkManager.Settings.SaveHostname()
-
callUpdate(Map<String, Map<String, DBusValue>> properties, {bool noAutoStart = false, bool allowInteractiveAuthorization = false})
→ Future<void>
-
Invokes org.freedesktop.NetworkManager.Settings.Connection.Update()
-
getAllProperties(String interface)
→ Future<Map<String, DBusValue>>
-
Gets the values of all the properties on this object.
inherited
-
getProperty(String interface, String name, {DBusSignature? signature})
→ Future<DBusValue>
-
Gets a property on this object.
inherited
-
introspect()
→ Future<DBusIntrospectNode>
-
Gets the introspection data for this object.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setProperty(String interface, String name, DBusValue value)
→ Future<void>
-
Sets a property on this object.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited