OrgFreedesktopNetworkManager class

Constructors

OrgFreedesktopNetworkManager(DBusClient client, String destination, {DBusObjectPath path = const DBusObjectPath.unchecked('/org/freedesktop/NetworkManager')})

Properties

client → DBusClient
The client this object is accessed from.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the client providing this object.
finalinherited
path → DBusObjectPath
The path to the object.
finalinherited
propertiesChanged Stream<DBusPropertiesChangedSignal>
Stream of signals when the remote object indicates a property has changed.
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callAddAndActivateConnection(Map<String, Map<String, DBusValue>> connection, DBusObjectPath device, DBusObjectPath specificObject, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) Future<List<DBusValue>>
Invokes org.freedesktop.NetworkManager.AddAndActivateConnection()
callGetAllAccessPoints({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) Future<List<DBusObjectPath>>
Invokes org.freedesktop.NetworkManager.Device.Wireless.GetAllAccessPoints()
callGetAllDevices({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) Future<List<DBusObjectPath>>
Invokes org.freedesktop.NetworkManager.GetAllDevices()
callMethod(String? interface, String name, Iterable<DBusValue> values, {DBusSignature? replySignature, bool noReplyExpected = false, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) Future<DBusMethodSuccessResponse>
Invokes a method on this object. Throws DBusMethodResponseException if the remote side returns an error.
inherited
callRequestScan(Map<String, DBusValue> options, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) Future<void>
Invokes org.freedesktop.NetworkManager.Device.Wireless.RequestScan()
getAccessPoints() Future<List<DBusObjectPath>>
Gets org.freedesktop.NetworkManager.Device.Wireless.AccessPoints
getActiveAccessPoint() Future<DBusObjectPath>
Gets org.freedesktop.NetworkManager.Device.Wireless.ActiveAccessPoint
getAllDevices() Future<List<DBusObjectPath>>
Gets org.freedesktop.NetworkManager.AllDevices
getAllProperties(String interface) Future<Map<String, DBusValue>>
Gets the values of all the properties on this object.
inherited
getDeviceType() Future<int>
Gets org.freedesktop.NetworkManager.Device.DeviceType
getFlags() Future<int>
Gets org.freedesktop.NetworkManager.AccessPoint.Flags
getHwAddress() Future<String>
Gets org.freedesktop.NetworkManager.AccessPoint.HwAddress
getLastSeen() Future<int>
Gets org.freedesktop.NetworkManager.AccessPoint.LastSeen
getMode() Future<int>
Gets org.freedesktop.NetworkManager.Device.Wireless.Mode
getMode_() Future<int>
Gets org.freedesktop.NetworkManager.AccessPoint.Mode
getProperty(String interface, String name, {DBusSignature? signature}) Future<DBusValue>
Gets a property on this object.
inherited
getRsnFlags() Future<int>
Gets org.freedesktop.NetworkManager.AccessPoint.RsnFlags
getSsid() Future<List<int>>
Gets org.freedesktop.NetworkManager.AccessPoint.Ssid
getStrength() Future<int>
Gets org.freedesktop.NetworkManager.AccessPoint.Strength
getWirelessEnabled() Future<bool>
Gets org.freedesktop.NetworkManager.WirelessEnabled
getWpaFlags() Future<int>
Gets org.freedesktop.NetworkManager.AccessPoint.WpaFlags
introspect() Future<DBusIntrospectNode>
Gets the introspection data for this object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProperty(String interface, String name, DBusValue value) Future<void>
Sets a property on this object.
inherited
setWirelessEnabled(bool value) Future<void>
Sets org.freedesktop.NetworkManager.WirelessEnabled
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited