WifiNetwork class

Represents a Wi-Fi network

Constructors

WifiNetwork({required String ssid, required String mac, required int strength, required DBusObjectPath path, required String security, required String mode})

Properties

hashCode int
The hash code for this object.
no setterinherited
mac String
final
mode String
final
path → DBusObjectPath
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
security String
final
ssid String
final
strength int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited